%bcond_without mpich
%global shortver %(echo %version|awk -F. '{print $1 "." $2}')

Name:		scalasca
Version:	2.6.1
Release:    2%{?dist}
Summary:	Toolset for performance analysis of large-scale parallel applications

License:	BSD-3-Clause AND GPL-3.0-or-later WITH Bison-exception-2.0
URL:		http://www.scalasca.org/
Source0:	http://apps.fz-juelich.de/scalasca/releases/scalasca/%shortver/dist/%name-%version.tar.gz
BuildRequires: make
BuildRequires:	otf2-devel >= 3.0, cube-devel >= 4.8
BuildRequires:	zlib-devel openmpi-devel chrpath gcc-c++
%if %{with mpich}
BuildRequires:	mpich-devel
%endif
Requires:	%_bindir/scorep-config
ExcludeArch: s390 s390x armv7hl i686

%global desc \
Scalasca is a software tool that supports the performance optimization\
of parallel programs by measuring and analyzing their runtime\
behavior. The analysis identifies potential performance bottlenecks –\
in particular those concerning communication and synchronization – and\
offers guidance in exploring their causes.\
\
Scalasca targets mainly scientific and engineering applications based\
on the programming interfaces MPI and OpenMP, including hybrid\
applications based on a combination of the two. The tool has been\
specifically designed for use on large-scale systems, but is also well\
suited for small- and medium-scale HPC platforms.

%description
%desc

%package openmpi
Summary:	Toolset for performance analysis of large-scale parallel applications - openmpi
Requires:	openmpi
Requires:	%_libdir/openmpi/bin/scorep-config

%description openmpi
%desc

%if %{with mpich}
%package mpich
Summary:	Toolset for performance analysis of large-scale parallel applications - mpich
Requires:	mpich
Requires:	%_libdir/mpich/bin/scorep-config

%description mpich
%desc

This is the mpich version.
%endif

%package doc
Summary: Documentation for %name
BuildArch: noarch

%description doc
Documentation for %name

%prep
%setup -q
mkdir openmpi mpich simple
rm -r vendor/cubew vendor/otf2	# bundled libraries


%build
%global _configure ../configure
%global do_build \
%configure --with-otf2 --with-cube --enable-shared --libdir=$MPI_LIB \\\
	   --bindir=$MPI_BIN --datadir=$MPI_HOME/share LDFLAGS=-Wl,--as-needed \\\
	   --enable-backend-test-runs --disable-silent-rules \\\
	   --mandir=$MPI_MAN --docdir=%_pkgdocdir \
	   %make_build
pushd openmpi
%_openmpi_load
%do_build
%_openmpi_unload
popd
%if %{with mpich}
pushd mpich
%_mpich_load
%do_build
%_mpich_unload
popd
%endif
pushd simple
%configure --with-otf2 --with-cube --enable-shared LDFLAGS=-Wl,--as-needed \
	   --enable-backend-test-runs --disable-silent-rules --without-mpi \
	   --docdir=%_pkgdocdir
%make_build
popd


%install
%make_install -C openmpi
%make_install -C simple
%if %{with mpich}
%make_install -C mpich
%endif
find %{buildroot}%_libdir \( -name \*.la -o -name \*.a \) -exec rm -f {} \;
chrpath -d %{buildroot}%_bindir/scout.{ser,omp}
chrpath -d %{buildroot}%_libdir/{openmpi,mpich}/bin/scout.{ser,omp}


%check



%files
%doc README
%license COPYING
%_datadir/%name
%exclude %_libdir/*.so
%_libdir/*.so.*
%_bindir/*
%_mandir/man1/*

%files openmpi
%doc README
%license COPYING
%_libdir/openmpi/share/%name
%exclude %_libdir/openmpi/lib/*.so
%_libdir/openmpi/lib/*.so.*
%_libdir/openmpi/bin/*
%_mandir/openmpi-*/man1/*


%if %{with mpich}
%files mpich
%doc README
%license COPYING
%_libdir/mpich/share/%name
%exclude %_libdir/mpich/lib/*.so
%_libdir/mpich/lib/*.so.*
%_libdir/mpich/bin/*
%_mandir/mpich*/man1/*
%endif

%files doc
%license COPYING
%_pkgdocdir


%changelog
* Thu Sep 12 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.6.1-2
- bump version

* Fri Apr 12 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.6.1-1
- initial build
